@@ -19,6 +19,7 @@
 #endif
 #include <string.h>
 #include <stdio.h>
+#include <algorithm>
 
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdk.h>
@@ -54,6 +55,10 @@ void preferences_dialog_set(const gchar *obj, gboolean b) {
 	if(!preferences_builder) get_preferences_dialog();
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_builder_get_object(preferences_builder, obj)), b);
 }
+void preferences_dialog_set_combo(const gchar *obj, int i) {
+	if(!preferences_builder) get_preferences_dialog();
+	gtk_combo_box_set_active(GTK_COMBO_BOX(gtk_builder_get_object(preferences_builder, obj)), i);
+}
 void on_colorbutton_text_color_color_set(GtkColorButton *w, gpointer) {
 	GdkRGBA c;
 	gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(w), &c);
@@ -305,6 +310,14 @@ void on_preferences_combo_history_expression_changed(GtkComboBox *w, gpointer) {
 	history_expression_type = gtk_combo_box_get_active(w);
 	reload_history();
 }
+extern int replace_expression;
+void on_preferences_combo_replace_expression_changed(GtkComboBox *w, gpointer) {
+	int index = gtk_combo_box_get_active(w);
+	if(index == 0) replace_expression = KEEP_EXPRESSION;
+	else if(index == 1) replace_expression = CLEAR_EXPRESSION;
+	else if(index == 2) replace_expression = REPLACE_EXPRESSION_WITH_RESULT;
+	else if(index == 3) replace_expression = REPLACE_EXPRESSION_WITH_RESULT_IF_SHORTER;
+}
 void on_preferences_checkbutton_copy_ascii_toggled(GtkToggleButton *w, gpointer) {
 	copy_ascii = gtk_toggle_button_get_active(w);
 	update_accels(SHORTCUT_TYPE_COPY_RESULT);
@@ -699,20 +712,49 @@ void on_preferences_radiobutton_division_toggled(GtkToggleButton *w, gpointer) {
 		result_display_updated();
 	}
 }
-void on_preferences_radiobutton_digit_grouping_none_toggled(GtkToggleButton *w, gpointer) {
-	if(gtk_toggle_button_get_active(w)) {
+extern bool custom_digit_grouping, custom_digit_group_changed;
+extern string custom_digit_group_separator, custom_digit_group_format, saved_local_dgs, saved_local_dgf;
+void on_preferences_cgs_entry_changed(GtkEntry *w, gpointer) {
+	if(!custom_digit_grouping) return;
+	custom_digit_group_separator = gtk_entry_get_text(w);
+	CALCULATOR->local_digit_group_separator = custom_digit_group_separator;
+	custom_digit_group_changed = true;
+	result_format_updated();
+}
+void on_preferences_cgf_spin_value_changed(GtkSpinButton *w, gpointer) {
+	if(!custom_digit_grouping) return;
+	custom_digit_group_format = '0' + gtk_spin_button_get_value(w);
+	CALCULATOR->local_digit_group_format = "";
+	for(size_t i = 0; i < custom_digit_group_format.size(); i++) {
+		CALCULATOR->local_digit_group_format += custom_digit_group_format[i] - '0';
+	}
+	custom_digit_group_changed = true;
+	result_format_updated();
+}
+void on_preferences_combo_digit_grouping_changed(GtkComboBox *w, gpointer) {
+	int i = gtk_combo_box_get_active(w);
+	if(custom_digit_grouping) {
+		CALCULATOR->local_digit_group_separator = saved_local_dgs;
+		CALCULATOR->local_digit_group_format = saved_local_dgf;
+	} else if(i == 3) {
+		saved_local_dgs = CALCULATOR->local_digit_group_separator;
+		saved_local_dgf = CALCULATOR->local_digit_group_format;
+	}
+	custom_digit_grouping = false;
+	if(i == 0) {
 		printops.digit_grouping = DIGIT_GROUPING_NONE;
 		result_format_updated();
-	}
-}
-void on_preferences_radiobutton_digit_grouping_standard_toggled(GtkToggleButton *w, gpointer) {
-	if(gtk_toggle_button_get_active(w)) {
+		gtk_adjustment_set_lower(GTK_ADJUSTMENT(gtk_builder_get_object(preferences_builder, "preferences_cgf_adjustment")), 0);
+		gtk_entry_set_text(GTK_ENTRY(gtk_builder_get_object(preferences_builder, "preferences_cgs_entry")), "");
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_cgf_spin")), 0);
+	} else if(i == 1) {
+		gtk_entry_set_text(GTK_ENTRY(gtk_builder_get_object(preferences_builder, "preferences_cgs_entry")), THIN_SPACE);
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_cgf_spin")), 3);
 		printops.digit_grouping = DIGIT_GROUPING_STANDARD;
 		result_format_updated();
-	}
-}
-void on_preferences_radiobutton_digit_grouping_locale_toggled(GtkToggleButton *w, gpointer) {
-	if(gtk_toggle_button_get_active(w)) {
+	} else if(i == 2) {
+		gtk_entry_set_text(GTK_ENTRY(gtk_builder_get_object(preferences_builder, "preferences_cgs_entry")), CALCULATOR->local_digit_group_separator.c_str());
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_cgf_spin")), CALCULATOR->local_digit_group_format.empty() || CALCULATOR->local_digit_group_format[0] == CHAR_MAX ? 3 : (int) CALCULATOR->local_digit_group_format[0]);
 		printops.digit_grouping = DIGIT_GROUPING_LOCALE;
 		if((!evalops.parse_options.comma_as_separator || CALCULATOR->getDecimalPoint() == COMMA) && CALCULATOR->local_digit_group_separator == COMMA) {
 			evalops.parse_options.comma_as_separator = true;
@@ -733,7 +775,21 @@ void on_preferences_radiobutton_digit_grouping_locale_toggled(GtkToggleButton *w
 		} else {
 			result_format_updated();
 		}
+	} else if(i == 3) {
+		gtk_adjustment_set_lower(GTK_ADJUSTMENT(gtk_builder_get_object(preferences_builder, "preferences_cgf_adjustment")), 1);
+		gtk_entry_set_text(GTK_ENTRY(gtk_builder_get_object(preferences_builder, "preferences_cgs_entry")), custom_digit_group_separator.c_str());
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_cgf_spin")), custom_digit_group_format.empty() ? 3 : custom_digit_group_format[0] - '0');
+		printops.digit_grouping = DIGIT_GROUPING_LOCALE;
+		CALCULATOR->local_digit_group_format = "";
+		for(size_t i = 0; i < custom_digit_group_format.size(); i++) {
+			CALCULATOR->local_digit_group_format += custom_digit_group_format[i] - '0';
+		}
+		CALCULATOR->local_digit_group_separator = custom_digit_group_separator;
+		custom_digit_grouping = true;
+		result_format_updated();
 	}
+	gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(preferences_builder, "preferences_cgs_entry")), custom_digit_grouping);
+	gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(preferences_builder, "preferences_cgf_spin")), custom_digit_grouping);
 }
 
 void on_preferences_checkbutton_enable_completion_toggled(GtkToggleButton *w, gpointer) {
@@ -773,6 +829,7 @@ void on_preferences_spin_completion_delay_value_changed(GtkSpinButton *spin, gpo
 	set_expression_completion_settings(-1, -1, -1, -1, gtk_spin_button_get_value_as_int(spin));
 }
 void preferences_update_completion(bool initial) {
+	if(!preferences_builder) return;
 	bool c1 = false, c2 = false;
 	int m1 = 0, m2 = 0, d = 0;
 	get_expression_completion_settings(&c1, &c2, &m1, &m2, &d);
@@ -838,6 +895,36 @@ void on_preferences_button_history_font_font_set(GtkFontButton *w, gpointer) {
 void on_preferences_button_app_font_font_set(GtkFontButton *w, gpointer) {
 	set_app_font(gtk_font_chooser_get_font(GTK_FONT_CHOOSER(w)));
 }
+extern string default_currency;
+void on_preferences_combo_local_currency_changed(GtkComboBox *w, gpointer) {
+	char *gstr = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(w));
+	if(gstr) {
+		string str = gstr;
+		default_currency = str.substr(str.length() - 4, 3);
+		Unit *u = CALCULATOR->getActiveUnit(default_currency);
+		if(u) CALCULATOR->setLocalCurrency(u);
+		g_free(gstr);
+	}
+}
+
+string ellipsize_title(const string &s, size_t n) {
+	if(unicode_length(s) <= n) return s;
+	n -= 1;
+	for(size_t i = 0; i < s.length(); i++) {
+		if((signed char) s[i] >= 0 || (unsigned char) s[i] >= 0xC0) {
+			n--;
+			if(s[i] == '(' && i > 0 && s[i - 1] == ' ') {
+				return s.substr(0, i);
+			} else if(n == 0) {
+				if((signed char) s[i] < 0) {
+					while((signed char) s[i + 1] < 0 && (unsigned char) s[i + 1] < 0xC0) i++;
+				}
+				return s.substr(0, i + 1) + "…";
+			}
+		}
+	}
+	return s;
+}
 
 GtkWidget* get_preferences_dialog() {
 	if(!preferences_builder) {
@@ -867,6 +954,11 @@ GtkWidget* get_preferences_dialog() {
 		gtk_combo_box_set_active(GTK_COMBO_BOX(gtk_builder_get_object(preferences_builder, "preferences_combo_tooltips")), enable_tooltips == 0 ? 2 : (enable_tooltips == 1 ? 0 : 1));
 		gtk_combo_box_set_active(GTK_COMBO_BOX(gtk_builder_get_object(preferences_builder, "preferences_combo_title")), title_type);
 		gtk_combo_box_set_active(GTK_COMBO_BOX(gtk_builder_get_object(preferences_builder, "preferences_combo_history_expression")), history_expression_type);
+		int index = 0;
+		if(replace_expression == CLEAR_EXPRESSION) index = 1;
+		else if(replace_expression == REPLACE_EXPRESSION_WITH_RESULT) index = 2;
+		else if(replace_expression == REPLACE_EXPRESSION_WITH_RESULT_IF_SHORTER) index = 3;
+		gtk_combo_box_set_active(GTK_COMBO_BOX(gtk_builder_get_object(preferences_builder, "preferences_combo_replace_expression")), index);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_checkbutton_unicode_signs")), printops.use_unicode_signs);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_checkbutton_copy_ascii")), copy_ascii);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_checkbutton_copy_ascii_without_units")), copy_ascii_without_units);
@@ -959,18 +1051,27 @@ GtkWidget* get_preferences_dialog() {
 		gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(preferences_builder, "preferences_radiobutton_division")), printops.use_unicode_signs);
 		switch(printops.digit_grouping) {
 			case DIGIT_GROUPING_STANDARD: {
-				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_radiobutton_digit_grouping_standard")), TRUE);
+				gtk_combo_box_set_active(GTK_COMBO_BOX(gtk_builder_get_object(preferences_builder, "preferences_combo_digit_grouping")), 1);
+				gtk_entry_set_text(GTK_ENTRY(gtk_builder_get_object(preferences_builder, "preferences_cgs_entry")), THIN_SPACE);
 				break;
 			}
 			case DIGIT_GROUPING_LOCALE: {
-				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_radiobutton_digit_grouping_locale")), TRUE);
+				gtk_adjustment_set_lower(GTK_ADJUSTMENT(gtk_builder_get_object(preferences_builder, "preferences_cgf_adjustment")), 1);
+				gtk_combo_box_set_active(GTK_COMBO_BOX(gtk_builder_get_object(preferences_builder, "preferences_combo_digit_grouping")), custom_digit_grouping ? 3 : 2);
+				gtk_entry_set_text(GTK_ENTRY(gtk_builder_get_object(preferences_builder, "preferences_cgs_entry")), CALCULATOR->local_digit_group_separator.c_str());
+				gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_cgf_spin")), CALCULATOR->local_digit_group_format.empty() || CALCULATOR->local_digit_group_format[0] == CHAR_MAX ? 3 : CALCULATOR->local_digit_group_format[0]);
 				break;
 			}
 			default: {
-				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_radiobutton_digit_grouping_none")), TRUE);
+				gtk_adjustment_set_lower(GTK_ADJUSTMENT(gtk_builder_get_object(preferences_builder, "preferences_cgf_adjustment")), 0);
+				gtk_combo_box_set_active(GTK_COMBO_BOX(gtk_builder_get_object(preferences_builder, "preferences_combo_digit_grouping")), 0);
+				gtk_entry_set_text(GTK_ENTRY(gtk_builder_get_object(preferences_builder, "preferences_cgs_entry")), "");
+				gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_cgf_spin")), 0);
 				break;
 			}
 		}
+		gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(preferences_builder, "preferences_cgs_entry")), custom_digit_grouping);
+		gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(preferences_builder, "preferences_cgf_spin")), custom_digit_grouping);
 		preferences_update_twos_complement(true);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_checkbutton_autocalc_history")), autocalc_history_delay >= 0 && !parsed_in_result);
 		gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(preferences_builder, "preferences_checkbutton_autocalc_history")), !parsed_in_result);
@@ -1030,13 +1131,27 @@ GtkWidget* get_preferences_dialog() {
 #endif
 		preferences_update_completion(true);
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(gtk_builder_get_object(preferences_builder, "preferences_update_exchange_rates_spin_button")), (double) exchange_rates_frequency());
+		vector<string> curs;
+		for(size_t i = 0; i < CALCULATOR->units.size(); i++) {
+			if(CALCULATOR->units[i]->isCurrency() && CALCULATOR->units[i]->referenceName().length() == 3) {
+				curs.push_back(ellipsize_title(CALCULATOR->units[i]->title(), 20) + string(" (") + CALCULATOR->units[i]->referenceName() + ")");
+			}
+		}
+		std::sort(curs.begin(), curs.end(), std::locale());
+		string scur;
+		if(CALCULATOR->getLocalCurrency()) scur = CALCULATOR->getLocalCurrency()->referenceName();
+		for(size_t i = 0; i < curs.size(); i++) {
+			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(gtk_builder_get_object(preferences_builder, "preferences_combo_local_currency")), curs[i].c_str());
+			if(curs[i].find(scur) == curs[i].length() - 4) gtk_combo_box_set_active(GTK_COMBO_BOX(gtk_builder_get_object(preferences_builder, "preferences_combo_local_currency")), i);
+		}
 
 		gtk_builder_add_callback_symbols(preferences_builder, "on_preferences_checkbutton_save_defs_toggled", G_CALLBACK(on_preferences_checkbutton_save_defs_toggled), "on_preferences_checkbutton_clear_history_toggled", G_CALLBACK(on_preferences_checkbutton_clear_history_toggled), "on_preferences_max_history_lines_spin_button_value_changed",
 		G_CALLBACK(on_preferences_max_history_lines_spin_button_value_changed), "on_preferences_checkbutton_save_history_separately_toggled",
 		G_CALLBACK(on_preferences_checkbutton_save_history_separately_toggled), "on_preferences_checkbutton_allow_multiple_instances_toggled",
 		G_CALLBACK(on_preferences_checkbutton_allow_multiple_instances_toggled), "on_preferences_checkbutton_check_version_toggled", G_CALLBACK(on_preferences_checkbutton_check_version_toggled), "on_preferences_checkbutton_save_mode_toggled", G_CALLBACK(on_preferences_checkbutton_save_mode_toggled), "on_preferences_checkbutton_close_with_esc_toggled",
 		G_CALLBACK(on_preferences_checkbutton_close_with_esc_toggled), "on_preferences_checkbutton_rpn_keys_toggled", G_CALLBACK(on_preferences_checkbutton_rpn_keys_toggled), "on_preferences_checkbutton_caret_as_xor_toggled", G_CALLBACK(on_preferences_checkbutton_caret_as_xor_toggled), "on_preferences_combo_history_expression_changed",
-		G_CALLBACK(on_preferences_combo_history_expression_changed), "on_preferences_checkbutton_autocalc_history_toggled", G_CALLBACK(on_preferences_checkbutton_autocalc_history_toggled), "on_preferences_scale_autocalc_history_value_changed", G_CALLBACK(on_preferences_scale_autocalc_history_value_changed), "on_preferences_scale_plot_time_value_changed",
+		G_CALLBACK(on_preferences_combo_history_expression_changed), "on_preferences_combo_replace_expression_changed",
+		G_CALLBACK(on_preferences_combo_replace_expression_changed), "on_preferences_checkbutton_autocalc_history_toggled", G_CALLBACK(on_preferences_checkbutton_autocalc_history_toggled), "on_preferences_scale_autocalc_history_value_changed", G_CALLBACK(on_preferences_scale_autocalc_history_value_changed), "on_preferences_scale_plot_time_value_changed",
 		G_CALLBACK(on_preferences_scale_plot_time_value_changed), "on_preferences_checkbutton_unicode_signs_toggled", G_CALLBACK(on_preferences_checkbutton_unicode_signs_toggled), "on_preferences_checkbutton_ignore_locale_toggled", G_CALLBACK(on_preferences_checkbutton_ignore_locale_toggled), "on_preferences_checkbutton_use_systray_icon_toggled",
 		G_CALLBACK(on_preferences_checkbutton_use_systray_icon_toggled), "on_preferences_checkbutton_hide_on_startup_toggled", G_CALLBACK(on_preferences_checkbutton_hide_on_startup_toggled), "on_preferences_checkbutton_remember_position_toggled", G_CALLBACK(on_preferences_checkbutton_remember_position_toggled), "on_preferences_checkbutton_keep_above_toggled",
 		G_CALLBACK(on_preferences_checkbutton_keep_above_toggled), "on_preferences_horizontal_padding_combo_changed", G_CALLBACK(on_preferences_horizontal_padding_combo_changed), "on_preferences_vertical_padding_combo_changed", G_CALLBACK(on_preferences_vertical_padding_combo_changed), "on_preferences_combo_title_changed", G_CALLBACK(on_preferences_combo_title_changed),
@@ -1049,12 +1164,13 @@ GtkWidget* get_preferences_dialog() {
 		G_CALLBACK(on_preferences_checkbutton_alternative_base_prefixes_toggled), "on_preferences_checkbutton_spell_out_logical_operators_toggled", G_CALLBACK(on_preferences_checkbutton_spell_out_logical_operators_toggled), "on_preferences_checkbutton_e_notation_toggled", G_CALLBACK(on_preferences_checkbutton_e_notation_toggled),
 		"on_preferences_checkbutton_lower_case_e_toggled", G_CALLBACK(on_preferences_checkbutton_lower_case_e_toggled), "on_preferences_checkbutton_repdeci_overline_toggled", G_CALLBACK(on_preferences_checkbutton_repdeci_overline_toggled), "on_preferences_checkbutton_decimal_comma_toggled", G_CALLBACK(on_preferences_checkbutton_decimal_comma_toggled), "on_preferences_checkbutton_imaginary_j_toggled", G_CALLBACK(on_preferences_checkbutton_imaginary_j_toggled),
 		"on_preferences_checkbutton_comma_as_separator_toggled", G_CALLBACK(on_preferences_checkbutton_comma_as_separator_toggled), "on_preferences_checkbutton_copy_ascii_toggled", G_CALLBACK(on_preferences_checkbutton_copy_ascii_toggled), "on_preferences_checkbutton_dot_as_separator_toggled", G_CALLBACK(on_preferences_checkbutton_dot_as_separator_toggled),
-		"on_preferences_radiobutton_digit_grouping_none_toggled", G_CALLBACK(on_preferences_radiobutton_digit_grouping_none_toggled), "on_preferences_radiobutton_digit_grouping_standard_toggled", G_CALLBACK(on_preferences_radiobutton_digit_grouping_standard_toggled), "on_preferences_radiobutton_digit_grouping_locale_toggled",
-		G_CALLBACK(on_preferences_radiobutton_digit_grouping_locale_toggled), "on_preferences_radiobutton_dot_toggled", G_CALLBACK(on_preferences_radiobutton_dot_toggled), "on_preferences_radiobutton_ex_toggled", G_CALLBACK(on_preferences_radiobutton_ex_toggled), "on_preferences_radiobutton_altdot_toggled", G_CALLBACK(on_preferences_radiobutton_altdot_toggled),
+		"on_preferences_combo_digit_grouping_changed", G_CALLBACK(on_preferences_combo_digit_grouping_changed),
+		"on_preferences_cgf_spin_value_changed", G_CALLBACK(on_preferences_cgf_spin_value_changed),
+		"on_preferences_cgs_entry_changed", G_CALLBACK(on_preferences_cgs_entry_changed), "on_preferences_radiobutton_dot_toggled", G_CALLBACK(on_preferences_radiobutton_dot_toggled), "on_preferences_radiobutton_ex_toggled", G_CALLBACK(on_preferences_radiobutton_ex_toggled), "on_preferences_radiobutton_altdot_toggled", G_CALLBACK(on_preferences_radiobutton_altdot_toggled),
 		"on_preferences_radiobutton_asterisk_toggled", G_CALLBACK(on_preferences_radiobutton_asterisk_toggled), "on_preferences_radiobutton_division_slash_toggled", G_CALLBACK(on_preferences_radiobutton_division_slash_toggled), "on_preferences_radiobutton_division_toggled", G_CALLBACK(on_preferences_radiobutton_division_toggled),
 		"on_preferences_radiobutton_slash_toggled", G_CALLBACK(on_preferences_radiobutton_slash_toggled), "on_preferences_checkbutton_binary_prefixes_toggled", G_CALLBACK(on_preferences_checkbutton_binary_prefixes_toggled), "on_preferences_checkbutton_copy_ascii_without_units_toggled",
 		G_CALLBACK(on_preferences_checkbutton_copy_ascii_without_units_toggled), "on_preferences_checkbutton_local_currency_conversion_toggled", G_CALLBACK(on_preferences_checkbutton_local_currency_conversion_toggled), "on_preferences_update_exchange_rates_spin_button_input", G_CALLBACK(on_preferences_update_exchange_rates_spin_button_input),
-		"on_preferences_update_exchange_rates_spin_button_output", G_CALLBACK(on_preferences_update_exchange_rates_spin_button_output), "on_preferences_update_exchange_rates_spin_button_value_changed", G_CALLBACK(on_preferences_update_exchange_rates_spin_button_value_changed), "on_preferences_radiobutton_temp_abs_toggled", G_CALLBACK(on_preferences_radiobutton_temp_abs_toggled),
+		"on_preferences_update_exchange_rates_spin_button_output", G_CALLBACK(on_preferences_update_exchange_rates_spin_button_output), "on_preferences_update_exchange_rates_spin_button_value_changed", G_CALLBACK(on_preferences_update_exchange_rates_spin_button_value_changed), "on_preferences_combo_local_currency_changed", G_CALLBACK(on_preferences_combo_local_currency_changed), "on_preferences_radiobutton_temp_abs_toggled", G_CALLBACK(on_preferences_radiobutton_temp_abs_toggled),
 		"on_preferences_radiobutton_temp_rel_toggled", G_CALLBACK(on_preferences_radiobutton_temp_rel_toggled), "on_preferences_radiobutton_temp_hybrid_toggled", G_CALLBACK(on_preferences_radiobutton_temp_hybrid_toggled), "on_preferences_checkbutton_enable_completion_toggled", G_CALLBACK(on_preferences_checkbutton_enable_completion_toggled),
 		"on_preferences_checkbutton_enable_completion2_toggled", G_CALLBACK(on_preferences_checkbutton_enable_completion2_toggled), "on_preferences_spin_completion_min_value_changed", G_CALLBACK(on_preferences_spin_completion_min_value_changed), "on_preferences_spin_completion_min2_value_changed", G_CALLBACK(on_preferences_spin_completion_min2_value_changed),
 		"on_preferences_spin_completion_delay_value_changed", G_CALLBACK(on_preferences_spin_completion_delay_value_changed), "on_preferences_checkbutton_custom_status_font_toggled", G_CALLBACK(on_preferences_checkbutton_custom_status_font_toggled), "on_preferences_button_status_font_font_set", G_CALLBACK(on_preferences_button_status_font_font_set),
